@@ -6,9 +6,7 @@ Time::Stats - Easy timing info
 
 =head1 SYNOPSIS
 
-use Time::Stats qw(mark clear stats);
-
-use Time::Stats ':all';
+use Time::Stats;
 
 clear();
 
@@ -16,6 +14,14 @@ mark();
 
 stats();
 
+# If you don't want to import the above methods:
+
+use Time::Stats ();
+
+Time::Stats::clear();
+Time::Stats::mark();
+Time::Stats::stats();
+
 =head1 DESCRIPTION
 
 This module is designed to make it very easy to get timing info for your code, ala Time::HiRes, without needing to remember tv_interval and [gettimeofday], or writing your own methods for processing data.  This is mainly useful if DProf doesn't give you useful info on what's slowing you down, and you need to inspect larger sections of code.
@@ -31,10 +37,9 @@ use Time::HiRes qw(tv_interval gettimeofday);
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(mark clear stats);
-our %EXPORT_TAGS = (all => [qw(mark clear stats)]);
+our @EXPORT = qw(mark clear stats);
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 our %last_caller_data;
 our %time_data;
